This is PDKMaster module to provide interoperation with klayout.
This is WIP version with just the red tape setup for the project.

## Release history

* v0.1.0: First version with split-off code from PDKMaster as is.

# Contributing

See [Contributing.md](Contributing.md)

# Licensing Rationale

Open source projects and it's surrounding community can only strive when improvements to the
code or application of the code itself are released to the public and allowed to be used by
them. Copyleft type license are using the licensing terms to guarantee this actually happens
and no party uses a 'take-but-don't-give-back' approach. The
[GNU Aferro General Public License V3.0](LICENSES/agpl-3.0.txt) is used as main license for
the code in this project as it is a copyleft type license that is also applicable to cloud
services without binary distribution of the code.

One of the problems with a strict copyleft license is that it can introduce incompatibilities
with code released under other open source licenses. In order to improve compatibility and
thus also re-usability the code in this repo is multi-licensed. Multi-licensing under
established open source licenses was preferred over custom extension of licenses.

The [GNU General Public License V2.0](LICENSES/gpl-2.0.txt) was added as optional license in
order to allow derived code not to be bound by the anti-[tivoization](
  https://en.wikipedia.org/wiki/Tivoization
) clauses introduced in the [GNU General Public License Version 3](
  https://www.gnu.org/licenses/gpl-3.0-standalone.html
). The latter was not deemed necessary for this project and the addition was done to increase
compatibility with some corporate policies.

The [CERN Open Hardware Licence Version 2 - Strongly Reciprocal](LICENSES/cern_ohl_s_v2.txt) is included as it is a copyleft license specifically targeted for hardware but incompatible
with the GPL licenses.

The [Apache License Version 2.0](LICENSES/apache-2.0.txt) is included to maximize compatibility
with existing open source code. One is supposed to not use it to avoid having to release one's
own derived code to the public. If you plan development of a project in a proprietary way, one
is kindly asked to not derive one's code from this project's code.

In future the list of allowed licenses may be reduced. A reason could be that such an action
is deemed necessary by the project maintainers to encourage open sourcing of derived code.

Analog to how the object files and the executables generated by the gcc compiler are not
necessarily governed by the GPL license, the multi-licensing applies only to code derived
from code in this repository. Output files generated through the use of the code in this
repository are not by default bound to the multi-licensing requirements of this project's
code.
